# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .activate_exadata_infrastructure_details import ActivateExadataInfrastructureDetails
from .associated_database_details import AssociatedDatabaseDetails
from .automated_mount_details import AutomatedMountDetails
from .autonomous_container_database import AutonomousContainerDatabase
from .autonomous_container_database_backup_config import AutonomousContainerDatabaseBackupConfig
from .autonomous_container_database_dataguard_association import AutonomousContainerDatabaseDataguardAssociation
from .autonomous_container_database_summary import AutonomousContainerDatabaseSummary
from .autonomous_data_warehouse import AutonomousDataWarehouse
from .autonomous_data_warehouse_connection_strings import AutonomousDataWarehouseConnectionStrings
from .autonomous_data_warehouse_summary import AutonomousDataWarehouseSummary
from .autonomous_database import AutonomousDatabase
from .autonomous_database_apex import AutonomousDatabaseApex
from .autonomous_database_backup import AutonomousDatabaseBackup
from .autonomous_database_backup_config import AutonomousDatabaseBackupConfig
from .autonomous_database_backup_summary import AutonomousDatabaseBackupSummary
from .autonomous_database_connection_strings import AutonomousDatabaseConnectionStrings
from .autonomous_database_connection_urls import AutonomousDatabaseConnectionUrls
from .autonomous_database_console_token_details import AutonomousDatabaseConsoleTokenDetails
from .autonomous_database_dataguard_association import AutonomousDatabaseDataguardAssociation
from .autonomous_database_key_history_entry import AutonomousDatabaseKeyHistoryEntry
from .autonomous_database_manual_refresh_details import AutonomousDatabaseManualRefreshDetails
from .autonomous_database_standby_summary import AutonomousDatabaseStandbySummary
from .autonomous_database_summary import AutonomousDatabaseSummary
from .autonomous_database_wallet import AutonomousDatabaseWallet
from .autonomous_db_preview_version_summary import AutonomousDbPreviewVersionSummary
from .autonomous_db_version_summary import AutonomousDbVersionSummary
from .autonomous_exadata_infrastructure import AutonomousExadataInfrastructure
from .autonomous_exadata_infrastructure_shape_summary import AutonomousExadataInfrastructureShapeSummary
from .autonomous_exadata_infrastructure_summary import AutonomousExadataInfrastructureSummary
from .autonomous_patch import AutonomousPatch
from .autonomous_patch_summary import AutonomousPatchSummary
from .autonomous_vm_cluster import AutonomousVmCluster
from .autonomous_vm_cluster_summary import AutonomousVmClusterSummary
from .backup import Backup
from .backup_destination import BackupDestination
from .backup_destination_details import BackupDestinationDetails
from .backup_destination_summary import BackupDestinationSummary
from .backup_summary import BackupSummary
from .change_autonomous_vm_cluster_compartment_details import ChangeAutonomousVmClusterCompartmentDetails
from .change_cloud_exadata_infrastructure_compartment_details import ChangeCloudExadataInfrastructureCompartmentDetails
from .change_cloud_vm_cluster_compartment_details import ChangeCloudVmClusterCompartmentDetails
from .change_compartment_details import ChangeCompartmentDetails
from .change_exadata_infrastructure_compartment_details import ChangeExadataInfrastructureCompartmentDetails
from .change_key_store_compartment_details import ChangeKeyStoreCompartmentDetails
from .change_vm_cluster_compartment_details import ChangeVmClusterCompartmentDetails
from .cloud_database_management_config import CloudDatabaseManagementConfig
from .cloud_exadata_infrastructure import CloudExadataInfrastructure
from .cloud_exadata_infrastructure_summary import CloudExadataInfrastructureSummary
from .cloud_vm_cluster import CloudVmCluster
from .cloud_vm_cluster_summary import CloudVmClusterSummary
from .complete_external_backup_job_details import CompleteExternalBackupJobDetails
from .configure_autonomous_database_vault_key_details import ConfigureAutonomousDatabaseVaultKeyDetails
from .console_connection import ConsoleConnection
from .console_connection_summary import ConsoleConnectionSummary
from .create_autonomous_container_database_details import CreateAutonomousContainerDatabaseDetails
from .create_autonomous_database_backup_details import CreateAutonomousDatabaseBackupDetails
from .create_autonomous_database_base import CreateAutonomousDatabaseBase
from .create_autonomous_database_clone_details import CreateAutonomousDatabaseCloneDetails
from .create_autonomous_database_details import CreateAutonomousDatabaseDetails
from .create_autonomous_database_from_backup_details import CreateAutonomousDatabaseFromBackupDetails
from .create_autonomous_database_from_backup_timestamp_details import CreateAutonomousDatabaseFromBackupTimestampDetails
from .create_autonomous_vm_cluster_details import CreateAutonomousVmClusterDetails
from .create_backup_destination_details import CreateBackupDestinationDetails
from .create_backup_details import CreateBackupDetails
from .create_cloud_exadata_infrastructure_details import CreateCloudExadataInfrastructureDetails
from .create_cloud_vm_cluster_details import CreateCloudVmClusterDetails
from .create_console_connection_details import CreateConsoleConnectionDetails
from .create_cross_region_autonomous_database_data_guard_details import CreateCrossRegionAutonomousDatabaseDataGuardDetails
from .create_data_guard_association_details import CreateDataGuardAssociationDetails
from .create_data_guard_association_to_existing_db_system_details import CreateDataGuardAssociationToExistingDbSystemDetails
from .create_data_guard_association_to_existing_vm_cluster_details import CreateDataGuardAssociationToExistingVmClusterDetails
from .create_data_guard_association_with_new_db_system_details import CreateDataGuardAssociationWithNewDbSystemDetails
from .create_database_base import CreateDatabaseBase
from .create_database_details import CreateDatabaseDetails
from .create_database_from_another_database_details import CreateDatabaseFromAnotherDatabaseDetails
from .create_database_from_backup import CreateDatabaseFromBackup
from .create_database_from_backup_details import CreateDatabaseFromBackupDetails
from .create_database_from_db_system_details import CreateDatabaseFromDbSystemDetails
from .create_database_software_image_details import CreateDatabaseSoftwareImageDetails
from .create_db_home_base import CreateDbHomeBase
from .create_db_home_details import CreateDbHomeDetails
from .create_db_home_from_backup_details import CreateDbHomeFromBackupDetails
from .create_db_home_from_database_details import CreateDbHomeFromDatabaseDetails
from .create_db_home_from_db_system_details import CreateDbHomeFromDbSystemDetails
from .create_db_home_with_db_system_id_details import CreateDbHomeWithDbSystemIdDetails
from .create_db_home_with_db_system_id_from_backup_details import CreateDbHomeWithDbSystemIdFromBackupDetails
from .create_db_home_with_db_system_id_from_database_details import CreateDbHomeWithDbSystemIdFromDatabaseDetails
from .create_db_home_with_vm_cluster_id_details import CreateDbHomeWithVmClusterIdDetails
from .create_db_home_with_vm_cluster_id_from_backup_details import CreateDbHomeWithVmClusterIdFromBackupDetails
from .create_exadata_infrastructure_details import CreateExadataInfrastructureDetails
from .create_external_backup_job_details import CreateExternalBackupJobDetails
from .create_external_container_database_details import CreateExternalContainerDatabaseDetails
from .create_external_database_connector_details import CreateExternalDatabaseConnectorDetails
from .create_external_database_details_base import CreateExternalDatabaseDetailsBase
from .create_external_macs_connector_details import CreateExternalMacsConnectorDetails
from .create_external_non_container_database_details import CreateExternalNonContainerDatabaseDetails
from .create_external_pluggable_database_details import CreateExternalPluggableDatabaseDetails
from .create_key_store_details import CreateKeyStoreDetails
from .create_nfs_backup_destination_details import CreateNFSBackupDestinationDetails
from .create_new_database_details import CreateNewDatabaseDetails
from .create_pluggable_database_details import CreatePluggableDatabaseDetails
from .create_recovery_appliance_backup_destination_details import CreateRecoveryApplianceBackupDestinationDetails
from .create_refreshable_autonomous_database_clone_details import CreateRefreshableAutonomousDatabaseCloneDetails
from .create_vm_cluster_details import CreateVmClusterDetails
from .customer_contact import CustomerContact
from .data_guard_association import DataGuardAssociation
from .data_guard_association_summary import DataGuardAssociationSummary
from .database import Database
from .database_connection_credentails_by_name import DatabaseConnectionCredentailsByName
from .database_connection_credentials import DatabaseConnectionCredentials
from .database_connection_credentials_by_details import DatabaseConnectionCredentialsByDetails
from .database_connection_string import DatabaseConnectionString
from .database_connection_string_profile import DatabaseConnectionStringProfile
from .database_connection_strings import DatabaseConnectionStrings
from .database_credential_details import DatabaseCredentialDetails
from .database_management_config import DatabaseManagementConfig
from .database_software_image import DatabaseSoftwareImage
from .database_software_image_summary import DatabaseSoftwareImageSummary
from .database_summary import DatabaseSummary
from .database_upgrade_history_entry import DatabaseUpgradeHistoryEntry
from .database_upgrade_history_entry_summary import DatabaseUpgradeHistoryEntrySummary
from .database_upgrade_source_base import DatabaseUpgradeSourceBase
from .database_upgrade_with_database_software_image_details import DatabaseUpgradeWithDatabaseSoftwareImageDetails
from .database_upgrade_with_db_home_details import DatabaseUpgradeWithDbHomeDetails
from .database_upgrade_with_db_version_details import DatabaseUpgradeWithDbVersionDetails
from .day_of_week import DayOfWeek
from .db_backup_config import DbBackupConfig
from .db_home import DbHome
from .db_home_from_agent_resource_id import DbHomeFromAgentResourceId
from .db_home_summary import DbHomeSummary
from .db_iorm_config import DbIormConfig
from .db_iorm_config_update_detail import DbIormConfigUpdateDetail
from .db_node import DbNode
from .db_node_summary import DbNodeSummary
from .db_system import DbSystem
from .db_system_options import DbSystemOptions
from .db_system_shape_summary import DbSystemShapeSummary
from .db_system_summary import DbSystemSummary
from .db_version_summary import DbVersionSummary
from .deregister_autonomous_database_data_safe_details import DeregisterAutonomousDatabaseDataSafeDetails
from .enable_database_management_details import EnableDatabaseManagementDetails
from .enable_external_container_database_database_management_details import EnableExternalContainerDatabaseDatabaseManagementDetails
from .enable_external_database_management_details_base import EnableExternalDatabaseManagementDetailsBase
from .enable_external_database_operations_insights_details_base import EnableExternalDatabaseOperationsInsightsDetailsBase
from .enable_external_non_container_database_database_management_details import EnableExternalNonContainerDatabaseDatabaseManagementDetails
from .enable_external_non_container_database_operations_insights_details import EnableExternalNonContainerDatabaseOperationsInsightsDetails
from .enable_external_pluggable_database_database_management_details import EnableExternalPluggableDatabaseDatabaseManagementDetails
from .enable_external_pluggable_database_operations_insights_details import EnableExternalPluggableDatabaseOperationsInsightsDetails
from .exadata_db_system_migration import ExadataDbSystemMigration
from .exadata_db_system_migration_summary import ExadataDbSystemMigrationSummary
from .exadata_infrastructure import ExadataInfrastructure
from .exadata_infrastructure_contact import ExadataInfrastructureContact
from .exadata_infrastructure_summary import ExadataInfrastructureSummary
from .exadata_iorm_config import ExadataIormConfig
from .exadata_iorm_config_update_details import ExadataIormConfigUpdateDetails
from .external_backup_job import ExternalBackupJob
from .external_container_database import ExternalContainerDatabase
from .external_container_database_summary import ExternalContainerDatabaseSummary
from .external_database_base import ExternalDatabaseBase
from .external_database_connector import ExternalDatabaseConnector
from .external_database_connector_summary import ExternalDatabaseConnectorSummary
from .external_macs_connector import ExternalMacsConnector
from .external_macs_connector_summary import ExternalMacsConnectorSummary
from .external_non_container_database import ExternalNonContainerDatabase
from .external_non_container_database_summary import ExternalNonContainerDatabaseSummary
from .external_pluggable_database import ExternalPluggableDatabase
from .external_pluggable_database_summary import ExternalPluggableDatabaseSummary
from .failover_data_guard_association_details import FailoverDataGuardAssociationDetails
from .flex_component_collection import FlexComponentCollection
from .flex_component_summary import FlexComponentSummary
from .generate_autonomous_database_wallet_details import GenerateAutonomousDatabaseWalletDetails
from .generate_recommended_network_details import GenerateRecommendedNetworkDetails
from .gi_version_summary import GiVersionSummary
from .info_for_network_gen_details import InfoForNetworkGenDetails
from .key_store import KeyStore
from .key_store_associated_database_details import KeyStoreAssociatedDatabaseDetails
from .key_store_summary import KeyStoreSummary
from .key_store_type_details import KeyStoreTypeDetails
from .key_store_type_from_oracle_key_vault_details import KeyStoreTypeFromOracleKeyVaultDetails
from .launch_autonomous_exadata_infrastructure_details import LaunchAutonomousExadataInfrastructureDetails
from .launch_db_system_base import LaunchDbSystemBase
from .launch_db_system_details import LaunchDbSystemDetails
from .launch_db_system_from_backup_details import LaunchDbSystemFromBackupDetails
from .launch_db_system_from_database_details import LaunchDbSystemFromDatabaseDetails
from .launch_db_system_from_db_system_details import LaunchDbSystemFromDbSystemDetails
from .local_clone_pluggable_database_details import LocalClonePluggableDatabaseDetails
from .maintenance_run import MaintenanceRun
from .maintenance_run_summary import MaintenanceRunSummary
from .maintenance_window import MaintenanceWindow
from .migrate_vault_key_details import MigrateVaultKeyDetails
from .modify_database_management_details import ModifyDatabaseManagementDetails
from .month import Month
from .mount_type_details import MountTypeDetails
from .node_details import NodeDetails
from .ocp_us import OCPUs
from .operations_insights_config import OperationsInsightsConfig
from .patch import Patch
from .patch_details import PatchDetails
from .patch_history_entry import PatchHistoryEntry
from .patch_history_entry_summary import PatchHistoryEntrySummary
from .patch_summary import PatchSummary
from .peer_autonomous_container_database_backup_config import PeerAutonomousContainerDatabaseBackupConfig
from .pluggable_database import PluggableDatabase
from .pluggable_database_connection_strings import PluggableDatabaseConnectionStrings
from .pluggable_database_summary import PluggableDatabaseSummary
from .register_autonomous_database_data_safe_details import RegisterAutonomousDatabaseDataSafeDetails
from .reinstate_data_guard_association_details import ReinstateDataGuardAssociationDetails
from .remote_clone_pluggable_database_details import RemoteClonePluggableDatabaseDetails
from .restore_autonomous_database_details import RestoreAutonomousDatabaseDetails
from .restore_database_details import RestoreDatabaseDetails
from .scan_details import ScanDetails
from .self_mount_details import SelfMountDetails
from .switchover_data_guard_association_details import SwitchoverDataGuardAssociationDetails
from .update import Update
from .update_autonomous_container_database_details import UpdateAutonomousContainerDatabaseDetails
from .update_autonomous_database_details import UpdateAutonomousDatabaseDetails
from .update_autonomous_database_wallet_details import UpdateAutonomousDatabaseWalletDetails
from .update_autonomous_exadata_infrastructure_details import UpdateAutonomousExadataInfrastructureDetails
from .update_autonomous_vm_cluster_details import UpdateAutonomousVmClusterDetails
from .update_backup_destination_details import UpdateBackupDestinationDetails
from .update_cloud_exadata_infrastructure_details import UpdateCloudExadataInfrastructureDetails
from .update_cloud_vm_cluster_details import UpdateCloudVmClusterDetails
from .update_data_guard_association_details import UpdateDataGuardAssociationDetails
from .update_database_details import UpdateDatabaseDetails
from .update_database_software_image_details import UpdateDatabaseSoftwareImageDetails
from .update_db_home_details import UpdateDbHomeDetails
from .update_db_system_details import UpdateDbSystemDetails
from .update_details import UpdateDetails
from .update_exadata_infrastructure_details import UpdateExadataInfrastructureDetails
from .update_external_container_database_details import UpdateExternalContainerDatabaseDetails
from .update_external_database_connector_details import UpdateExternalDatabaseConnectorDetails
from .update_external_database_details_base import UpdateExternalDatabaseDetailsBase
from .update_external_macs_connector_details import UpdateExternalMacsConnectorDetails
from .update_external_non_container_database_details import UpdateExternalNonContainerDatabaseDetails
from .update_external_pluggable_database_details import UpdateExternalPluggableDatabaseDetails
from .update_history_entry import UpdateHistoryEntry
from .update_history_entry_summary import UpdateHistoryEntrySummary
from .update_key_store_details import UpdateKeyStoreDetails
from .update_maintenance_run_details import UpdateMaintenanceRunDetails
from .update_pluggable_database_details import UpdatePluggableDatabaseDetails
from .update_summary import UpdateSummary
from .update_vm_cluster_details import UpdateVmClusterDetails
from .update_vm_cluster_network_details import UpdateVmClusterNetworkDetails
from .upgrade_database_details import UpgradeDatabaseDetails
from .vm_cluster import VmCluster
from .vm_cluster_network import VmClusterNetwork
from .vm_cluster_network_details import VmClusterNetworkDetails
from .vm_cluster_network_summary import VmClusterNetworkSummary
from .vm_cluster_summary import VmClusterSummary
from .vm_cluster_update import VmClusterUpdate
from .vm_cluster_update_details import VmClusterUpdateDetails
from .vm_cluster_update_history_entry import VmClusterUpdateHistoryEntry
from .vm_cluster_update_history_entry_summary import VmClusterUpdateHistoryEntrySummary
from .vm_cluster_update_summary import VmClusterUpdateSummary
from .vm_network_details import VmNetworkDetails
from .workload_type import WorkloadType

# Maps type names to classes for database services.
database_type_mapping = {
    "ActivateExadataInfrastructureDetails": ActivateExadataInfrastructureDetails,
    "AssociatedDatabaseDetails": AssociatedDatabaseDetails,
    "AutomatedMountDetails": AutomatedMountDetails,
    "AutonomousContainerDatabase": AutonomousContainerDatabase,
    "AutonomousContainerDatabaseBackupConfig": AutonomousContainerDatabaseBackupConfig,
    "AutonomousContainerDatabaseDataguardAssociation": AutonomousContainerDatabaseDataguardAssociation,
    "AutonomousContainerDatabaseSummary": AutonomousContainerDatabaseSummary,
    "AutonomousDataWarehouse": AutonomousDataWarehouse,
    "AutonomousDataWarehouseConnectionStrings": AutonomousDataWarehouseConnectionStrings,
    "AutonomousDataWarehouseSummary": AutonomousDataWarehouseSummary,
    "AutonomousDatabase": AutonomousDatabase,
    "AutonomousDatabaseApex": AutonomousDatabaseApex,
    "AutonomousDatabaseBackup": AutonomousDatabaseBackup,
    "AutonomousDatabaseBackupConfig": AutonomousDatabaseBackupConfig,
    "AutonomousDatabaseBackupSummary": AutonomousDatabaseBackupSummary,
    "AutonomousDatabaseConnectionStrings": AutonomousDatabaseConnectionStrings,
    "AutonomousDatabaseConnectionUrls": AutonomousDatabaseConnectionUrls,
    "AutonomousDatabaseConsoleTokenDetails": AutonomousDatabaseConsoleTokenDetails,
    "AutonomousDatabaseDataguardAssociation": AutonomousDatabaseDataguardAssociation,
    "AutonomousDatabaseKeyHistoryEntry": AutonomousDatabaseKeyHistoryEntry,
    "AutonomousDatabaseManualRefreshDetails": AutonomousDatabaseManualRefreshDetails,
    "AutonomousDatabaseStandbySummary": AutonomousDatabaseStandbySummary,
    "AutonomousDatabaseSummary": AutonomousDatabaseSummary,
    "AutonomousDatabaseWallet": AutonomousDatabaseWallet,
    "AutonomousDbPreviewVersionSummary": AutonomousDbPreviewVersionSummary,
    "AutonomousDbVersionSummary": AutonomousDbVersionSummary,
    "AutonomousExadataInfrastructure": AutonomousExadataInfrastructure,
    "AutonomousExadataInfrastructureShapeSummary": AutonomousExadataInfrastructureShapeSummary,
    "AutonomousExadataInfrastructureSummary": AutonomousExadataInfrastructureSummary,
    "AutonomousPatch": AutonomousPatch,
    "AutonomousPatchSummary": AutonomousPatchSummary,
    "AutonomousVmCluster": AutonomousVmCluster,
    "AutonomousVmClusterSummary": AutonomousVmClusterSummary,
    "Backup": Backup,
    "BackupDestination": BackupDestination,
    "BackupDestinationDetails": BackupDestinationDetails,
    "BackupDestinationSummary": BackupDestinationSummary,
    "BackupSummary": BackupSummary,
    "ChangeAutonomousVmClusterCompartmentDetails": ChangeAutonomousVmClusterCompartmentDetails,
    "ChangeCloudExadataInfrastructureCompartmentDetails": ChangeCloudExadataInfrastructureCompartmentDetails,
    "ChangeCloudVmClusterCompartmentDetails": ChangeCloudVmClusterCompartmentDetails,
    "ChangeCompartmentDetails": ChangeCompartmentDetails,
    "ChangeExadataInfrastructureCompartmentDetails": ChangeExadataInfrastructureCompartmentDetails,
    "ChangeKeyStoreCompartmentDetails": ChangeKeyStoreCompartmentDetails,
    "ChangeVmClusterCompartmentDetails": ChangeVmClusterCompartmentDetails,
    "CloudDatabaseManagementConfig": CloudDatabaseManagementConfig,
    "CloudExadataInfrastructure": CloudExadataInfrastructure,
    "CloudExadataInfrastructureSummary": CloudExadataInfrastructureSummary,
    "CloudVmCluster": CloudVmCluster,
    "CloudVmClusterSummary": CloudVmClusterSummary,
    "CompleteExternalBackupJobDetails": CompleteExternalBackupJobDetails,
    "ConfigureAutonomousDatabaseVaultKeyDetails": ConfigureAutonomousDatabaseVaultKeyDetails,
    "ConsoleConnection": ConsoleConnection,
    "ConsoleConnectionSummary": ConsoleConnectionSummary,
    "CreateAutonomousContainerDatabaseDetails": CreateAutonomousContainerDatabaseDetails,
    "CreateAutonomousDatabaseBackupDetails": CreateAutonomousDatabaseBackupDetails,
    "CreateAutonomousDatabaseBase": CreateAutonomousDatabaseBase,
    "CreateAutonomousDatabaseCloneDetails": CreateAutonomousDatabaseCloneDetails,
    "CreateAutonomousDatabaseDetails": CreateAutonomousDatabaseDetails,
    "CreateAutonomousDatabaseFromBackupDetails": CreateAutonomousDatabaseFromBackupDetails,
    "CreateAutonomousDatabaseFromBackupTimestampDetails": CreateAutonomousDatabaseFromBackupTimestampDetails,
    "CreateAutonomousVmClusterDetails": CreateAutonomousVmClusterDetails,
    "CreateBackupDestinationDetails": CreateBackupDestinationDetails,
    "CreateBackupDetails": CreateBackupDetails,
    "CreateCloudExadataInfrastructureDetails": CreateCloudExadataInfrastructureDetails,
    "CreateCloudVmClusterDetails": CreateCloudVmClusterDetails,
    "CreateConsoleConnectionDetails": CreateConsoleConnectionDetails,
    "CreateCrossRegionAutonomousDatabaseDataGuardDetails": CreateCrossRegionAutonomousDatabaseDataGuardDetails,
    "CreateDataGuardAssociationDetails": CreateDataGuardAssociationDetails,
    "CreateDataGuardAssociationToExistingDbSystemDetails": CreateDataGuardAssociationToExistingDbSystemDetails,
    "CreateDataGuardAssociationToExistingVmClusterDetails": CreateDataGuardAssociationToExistingVmClusterDetails,
    "CreateDataGuardAssociationWithNewDbSystemDetails": CreateDataGuardAssociationWithNewDbSystemDetails,
    "CreateDatabaseBase": CreateDatabaseBase,
    "CreateDatabaseDetails": CreateDatabaseDetails,
    "CreateDatabaseFromAnotherDatabaseDetails": CreateDatabaseFromAnotherDatabaseDetails,
    "CreateDatabaseFromBackup": CreateDatabaseFromBackup,
    "CreateDatabaseFromBackupDetails": CreateDatabaseFromBackupDetails,
    "CreateDatabaseFromDbSystemDetails": CreateDatabaseFromDbSystemDetails,
    "CreateDatabaseSoftwareImageDetails": CreateDatabaseSoftwareImageDetails,
    "CreateDbHomeBase": CreateDbHomeBase,
    "CreateDbHomeDetails": CreateDbHomeDetails,
    "CreateDbHomeFromBackupDetails": CreateDbHomeFromBackupDetails,
    "CreateDbHomeFromDatabaseDetails": CreateDbHomeFromDatabaseDetails,
    "CreateDbHomeFromDbSystemDetails": CreateDbHomeFromDbSystemDetails,
    "CreateDbHomeWithDbSystemIdDetails": CreateDbHomeWithDbSystemIdDetails,
    "CreateDbHomeWithDbSystemIdFromBackupDetails": CreateDbHomeWithDbSystemIdFromBackupDetails,
    "CreateDbHomeWithDbSystemIdFromDatabaseDetails": CreateDbHomeWithDbSystemIdFromDatabaseDetails,
    "CreateDbHomeWithVmClusterIdDetails": CreateDbHomeWithVmClusterIdDetails,
    "CreateDbHomeWithVmClusterIdFromBackupDetails": CreateDbHomeWithVmClusterIdFromBackupDetails,
    "CreateExadataInfrastructureDetails": CreateExadataInfrastructureDetails,
    "CreateExternalBackupJobDetails": CreateExternalBackupJobDetails,
    "CreateExternalContainerDatabaseDetails": CreateExternalContainerDatabaseDetails,
    "CreateExternalDatabaseConnectorDetails": CreateExternalDatabaseConnectorDetails,
    "CreateExternalDatabaseDetailsBase": CreateExternalDatabaseDetailsBase,
    "CreateExternalMacsConnectorDetails": CreateExternalMacsConnectorDetails,
    "CreateExternalNonContainerDatabaseDetails": CreateExternalNonContainerDatabaseDetails,
    "CreateExternalPluggableDatabaseDetails": CreateExternalPluggableDatabaseDetails,
    "CreateKeyStoreDetails": CreateKeyStoreDetails,
    "CreateNFSBackupDestinationDetails": CreateNFSBackupDestinationDetails,
    "CreateNewDatabaseDetails": CreateNewDatabaseDetails,
    "CreatePluggableDatabaseDetails": CreatePluggableDatabaseDetails,
    "CreateRecoveryApplianceBackupDestinationDetails": CreateRecoveryApplianceBackupDestinationDetails,
    "CreateRefreshableAutonomousDatabaseCloneDetails": CreateRefreshableAutonomousDatabaseCloneDetails,
    "CreateVmClusterDetails": CreateVmClusterDetails,
    "CustomerContact": CustomerContact,
    "DataGuardAssociation": DataGuardAssociation,
    "DataGuardAssociationSummary": DataGuardAssociationSummary,
    "Database": Database,
    "DatabaseConnectionCredentailsByName": DatabaseConnectionCredentailsByName,
    "DatabaseConnectionCredentials": DatabaseConnectionCredentials,
    "DatabaseConnectionCredentialsByDetails": DatabaseConnectionCredentialsByDetails,
    "DatabaseConnectionString": DatabaseConnectionString,
    "DatabaseConnectionStringProfile": DatabaseConnectionStringProfile,
    "DatabaseConnectionStrings": DatabaseConnectionStrings,
    "DatabaseCredentialDetails": DatabaseCredentialDetails,
    "DatabaseManagementConfig": DatabaseManagementConfig,
    "DatabaseSoftwareImage": DatabaseSoftwareImage,
    "DatabaseSoftwareImageSummary": DatabaseSoftwareImageSummary,
    "DatabaseSummary": DatabaseSummary,
    "DatabaseUpgradeHistoryEntry": DatabaseUpgradeHistoryEntry,
    "DatabaseUpgradeHistoryEntrySummary": DatabaseUpgradeHistoryEntrySummary,
    "DatabaseUpgradeSourceBase": DatabaseUpgradeSourceBase,
    "DatabaseUpgradeWithDatabaseSoftwareImageDetails": DatabaseUpgradeWithDatabaseSoftwareImageDetails,
    "DatabaseUpgradeWithDbHomeDetails": DatabaseUpgradeWithDbHomeDetails,
    "DatabaseUpgradeWithDbVersionDetails": DatabaseUpgradeWithDbVersionDetails,
    "DayOfWeek": DayOfWeek,
    "DbBackupConfig": DbBackupConfig,
    "DbHome": DbHome,
    "DbHomeFromAgentResourceId": DbHomeFromAgentResourceId,
    "DbHomeSummary": DbHomeSummary,
    "DbIormConfig": DbIormConfig,
    "DbIormConfigUpdateDetail": DbIormConfigUpdateDetail,
    "DbNode": DbNode,
    "DbNodeSummary": DbNodeSummary,
    "DbSystem": DbSystem,
    "DbSystemOptions": DbSystemOptions,
    "DbSystemShapeSummary": DbSystemShapeSummary,
    "DbSystemSummary": DbSystemSummary,
    "DbVersionSummary": DbVersionSummary,
    "DeregisterAutonomousDatabaseDataSafeDetails": DeregisterAutonomousDatabaseDataSafeDetails,
    "EnableDatabaseManagementDetails": EnableDatabaseManagementDetails,
    "EnableExternalContainerDatabaseDatabaseManagementDetails": EnableExternalContainerDatabaseDatabaseManagementDetails,
    "EnableExternalDatabaseManagementDetailsBase": EnableExternalDatabaseManagementDetailsBase,
    "EnableExternalDatabaseOperationsInsightsDetailsBase": EnableExternalDatabaseOperationsInsightsDetailsBase,
    "EnableExternalNonContainerDatabaseDatabaseManagementDetails": EnableExternalNonContainerDatabaseDatabaseManagementDetails,
    "EnableExternalNonContainerDatabaseOperationsInsightsDetails": EnableExternalNonContainerDatabaseOperationsInsightsDetails,
    "EnableExternalPluggableDatabaseDatabaseManagementDetails": EnableExternalPluggableDatabaseDatabaseManagementDetails,
    "EnableExternalPluggableDatabaseOperationsInsightsDetails": EnableExternalPluggableDatabaseOperationsInsightsDetails,
    "ExadataDbSystemMigration": ExadataDbSystemMigration,
    "ExadataDbSystemMigrationSummary": ExadataDbSystemMigrationSummary,
    "ExadataInfrastructure": ExadataInfrastructure,
    "ExadataInfrastructureContact": ExadataInfrastructureContact,
    "ExadataInfrastructureSummary": ExadataInfrastructureSummary,
    "ExadataIormConfig": ExadataIormConfig,
    "ExadataIormConfigUpdateDetails": ExadataIormConfigUpdateDetails,
    "ExternalBackupJob": ExternalBackupJob,
    "ExternalContainerDatabase": ExternalContainerDatabase,
    "ExternalContainerDatabaseSummary": ExternalContainerDatabaseSummary,
    "ExternalDatabaseBase": ExternalDatabaseBase,
    "ExternalDatabaseConnector": ExternalDatabaseConnector,
    "ExternalDatabaseConnectorSummary": ExternalDatabaseConnectorSummary,
    "ExternalMacsConnector": ExternalMacsConnector,
    "ExternalMacsConnectorSummary": ExternalMacsConnectorSummary,
    "ExternalNonContainerDatabase": ExternalNonContainerDatabase,
    "ExternalNonContainerDatabaseSummary": ExternalNonContainerDatabaseSummary,
    "ExternalPluggableDatabase": ExternalPluggableDatabase,
    "ExternalPluggableDatabaseSummary": ExternalPluggableDatabaseSummary,
    "FailoverDataGuardAssociationDetails": FailoverDataGuardAssociationDetails,
    "FlexComponentCollection": FlexComponentCollection,
    "FlexComponentSummary": FlexComponentSummary,
    "GenerateAutonomousDatabaseWalletDetails": GenerateAutonomousDatabaseWalletDetails,
    "GenerateRecommendedNetworkDetails": GenerateRecommendedNetworkDetails,
    "GiVersionSummary": GiVersionSummary,
    "InfoForNetworkGenDetails": InfoForNetworkGenDetails,
    "KeyStore": KeyStore,
    "KeyStoreAssociatedDatabaseDetails": KeyStoreAssociatedDatabaseDetails,
    "KeyStoreSummary": KeyStoreSummary,
    "KeyStoreTypeDetails": KeyStoreTypeDetails,
    "KeyStoreTypeFromOracleKeyVaultDetails": KeyStoreTypeFromOracleKeyVaultDetails,
    "LaunchAutonomousExadataInfrastructureDetails": LaunchAutonomousExadataInfrastructureDetails,
    "LaunchDbSystemBase": LaunchDbSystemBase,
    "LaunchDbSystemDetails": LaunchDbSystemDetails,
    "LaunchDbSystemFromBackupDetails": LaunchDbSystemFromBackupDetails,
    "LaunchDbSystemFromDatabaseDetails": LaunchDbSystemFromDatabaseDetails,
    "LaunchDbSystemFromDbSystemDetails": LaunchDbSystemFromDbSystemDetails,
    "LocalClonePluggableDatabaseDetails": LocalClonePluggableDatabaseDetails,
    "MaintenanceRun": MaintenanceRun,
    "MaintenanceRunSummary": MaintenanceRunSummary,
    "MaintenanceWindow": MaintenanceWindow,
    "MigrateVaultKeyDetails": MigrateVaultKeyDetails,
    "ModifyDatabaseManagementDetails": ModifyDatabaseManagementDetails,
    "Month": Month,
    "MountTypeDetails": MountTypeDetails,
    "NodeDetails": NodeDetails,
    "OCPUs": OCPUs,
    "OperationsInsightsConfig": OperationsInsightsConfig,
    "Patch": Patch,
    "PatchDetails": PatchDetails,
    "PatchHistoryEntry": PatchHistoryEntry,
    "PatchHistoryEntrySummary": PatchHistoryEntrySummary,
    "PatchSummary": PatchSummary,
    "PeerAutonomousContainerDatabaseBackupConfig": PeerAutonomousContainerDatabaseBackupConfig,
    "PluggableDatabase": PluggableDatabase,
    "PluggableDatabaseConnectionStrings": PluggableDatabaseConnectionStrings,
    "PluggableDatabaseSummary": PluggableDatabaseSummary,
    "RegisterAutonomousDatabaseDataSafeDetails": RegisterAutonomousDatabaseDataSafeDetails,
    "ReinstateDataGuardAssociationDetails": ReinstateDataGuardAssociationDetails,
    "RemoteClonePluggableDatabaseDetails": RemoteClonePluggableDatabaseDetails,
    "RestoreAutonomousDatabaseDetails": RestoreAutonomousDatabaseDetails,
    "RestoreDatabaseDetails": RestoreDatabaseDetails,
    "ScanDetails": ScanDetails,
    "SelfMountDetails": SelfMountDetails,
    "SwitchoverDataGuardAssociationDetails": SwitchoverDataGuardAssociationDetails,
    "Update": Update,
    "UpdateAutonomousContainerDatabaseDetails": UpdateAutonomousContainerDatabaseDetails,
    "UpdateAutonomousDatabaseDetails": UpdateAutonomousDatabaseDetails,
    "UpdateAutonomousDatabaseWalletDetails": UpdateAutonomousDatabaseWalletDetails,
    "UpdateAutonomousExadataInfrastructureDetails": UpdateAutonomousExadataInfrastructureDetails,
    "UpdateAutonomousVmClusterDetails": UpdateAutonomousVmClusterDetails,
    "UpdateBackupDestinationDetails": UpdateBackupDestinationDetails,
    "UpdateCloudExadataInfrastructureDetails": UpdateCloudExadataInfrastructureDetails,
    "UpdateCloudVmClusterDetails": UpdateCloudVmClusterDetails,
    "UpdateDataGuardAssociationDetails": UpdateDataGuardAssociationDetails,
    "UpdateDatabaseDetails": UpdateDatabaseDetails,
    "UpdateDatabaseSoftwareImageDetails": UpdateDatabaseSoftwareImageDetails,
    "UpdateDbHomeDetails": UpdateDbHomeDetails,
    "UpdateDbSystemDetails": UpdateDbSystemDetails,
    "UpdateDetails": UpdateDetails,
    "UpdateExadataInfrastructureDetails": UpdateExadataInfrastructureDetails,
    "UpdateExternalContainerDatabaseDetails": UpdateExternalContainerDatabaseDetails,
    "UpdateExternalDatabaseConnectorDetails": UpdateExternalDatabaseConnectorDetails,
    "UpdateExternalDatabaseDetailsBase": UpdateExternalDatabaseDetailsBase,
    "UpdateExternalMacsConnectorDetails": UpdateExternalMacsConnectorDetails,
    "UpdateExternalNonContainerDatabaseDetails": UpdateExternalNonContainerDatabaseDetails,
    "UpdateExternalPluggableDatabaseDetails": UpdateExternalPluggableDatabaseDetails,
    "UpdateHistoryEntry": UpdateHistoryEntry,
    "UpdateHistoryEntrySummary": UpdateHistoryEntrySummary,
    "UpdateKeyStoreDetails": UpdateKeyStoreDetails,
    "UpdateMaintenanceRunDetails": UpdateMaintenanceRunDetails,
    "UpdatePluggableDatabaseDetails": UpdatePluggableDatabaseDetails,
    "UpdateSummary": UpdateSummary,
    "UpdateVmClusterDetails": UpdateVmClusterDetails,
    "UpdateVmClusterNetworkDetails": UpdateVmClusterNetworkDetails,
    "UpgradeDatabaseDetails": UpgradeDatabaseDetails,
    "VmCluster": VmCluster,
    "VmClusterNetwork": VmClusterNetwork,
    "VmClusterNetworkDetails": VmClusterNetworkDetails,
    "VmClusterNetworkSummary": VmClusterNetworkSummary,
    "VmClusterSummary": VmClusterSummary,
    "VmClusterUpdate": VmClusterUpdate,
    "VmClusterUpdateDetails": VmClusterUpdateDetails,
    "VmClusterUpdateHistoryEntry": VmClusterUpdateHistoryEntry,
    "VmClusterUpdateHistoryEntrySummary": VmClusterUpdateHistoryEntrySummary,
    "VmClusterUpdateSummary": VmClusterUpdateSummary,
    "VmNetworkDetails": VmNetworkDetails,
    "WorkloadType": WorkloadType
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAutonomousDatabaseBackupDetails(object):
    """
    Details to create an Oracle Autonomous Database backup.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAutonomousDatabaseBackupDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateAutonomousDatabaseBackupDetails.
        :type display_name: str

        :param autonomous_database_id:
            The value to assign to the autonomous_database_id property of this CreateAutonomousDatabaseBackupDetails.
        :type autonomous_database_id: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'autonomous_database_id': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'autonomous_database_id': 'autonomousDatabaseId'
        }

        self._display_name = None
        self._autonomous_database_id = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateAutonomousDatabaseBackupDetails.
        The user-friendly name for the backup. The name does not have to be unique.


        :return: The display_name of this CreateAutonomousDatabaseBackupDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateAutonomousDatabaseBackupDetails.
        The user-friendly name for the backup. The name does not have to be unique.


        :param display_name: The display_name of this CreateAutonomousDatabaseBackupDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def autonomous_database_id(self):
        """
        **[Required]** Gets the autonomous_database_id of this CreateAutonomousDatabaseBackupDetails.
        The `OCID`__ of the Autonomous Database backup.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The autonomous_database_id of this CreateAutonomousDatabaseBackupDetails.
        :rtype: str
        """
        return self._autonomous_database_id

    @autonomous_database_id.setter
    def autonomous_database_id(self, autonomous_database_id):
        """
        Sets the autonomous_database_id of this CreateAutonomousDatabaseBackupDetails.
        The `OCID`__ of the Autonomous Database backup.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param autonomous_database_id: The autonomous_database_id of this CreateAutonomousDatabaseBackupDetails.
        :type: str
        """
        self._autonomous_database_id = autonomous_database_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .ca_certificate import CaCertificate
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PemCaCertificate(CaCertificate):
    """
    The CA certificate in PEM format.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PemCaCertificate object with values from keyword arguments. The default value of the :py:attr:`~oci.mysql.models.PemCaCertificate.certificate_type` attribute
        of this class is ``PEM`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param certificate_type:
            The value to assign to the certificate_type property of this PemCaCertificate.
            Allowed values for this property are: "PEM"
        :type certificate_type: str

        :param contents:
            The value to assign to the contents property of this PemCaCertificate.
        :type contents: str

        """
        self.swagger_types = {
            'certificate_type': 'str',
            'contents': 'str'
        }

        self.attribute_map = {
            'certificate_type': 'certificateType',
            'contents': 'contents'
        }

        self._certificate_type = None
        self._contents = None
        self._certificate_type = 'PEM'

    @property
    def contents(self):
        """
        **[Required]** Gets the contents of this PemCaCertificate.
        The string containing the CA certificate in PEM format.


        :return: The contents of this PemCaCertificate.
        :rtype: str
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """
        Sets the contents of this PemCaCertificate.
        The string containing the CA certificate in PEM format.


        :param contents: The contents of this PemCaCertificate.
        :type: str
        """
        self._contents = contents

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_task_details import UpdateTaskDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateTaskFromSQLTask(UpdateTaskDetails):
    """
    The information about the SQL task.
    """

    #: A constant which can be used with the sql_script_type property of a UpdateTaskFromSQLTask.
    #: This constant has a value of "STORED_PROCEDURE"
    SQL_SCRIPT_TYPE_STORED_PROCEDURE = "STORED_PROCEDURE"

    #: A constant which can be used with the sql_script_type property of a UpdateTaskFromSQLTask.
    #: This constant has a value of "SQL_CODE"
    SQL_SCRIPT_TYPE_SQL_CODE = "SQL_CODE"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateTaskFromSQLTask object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.UpdateTaskFromSQLTask.model_type` attribute
        of this class is ``SQL_TASK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this UpdateTaskFromSQLTask.
            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK"
        :type model_type: str

        :param key:
            The value to assign to the key property of this UpdateTaskFromSQLTask.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this UpdateTaskFromSQLTask.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this UpdateTaskFromSQLTask.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this UpdateTaskFromSQLTask.
        :type name: str

        :param description:
            The value to assign to the description property of this UpdateTaskFromSQLTask.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this UpdateTaskFromSQLTask.
        :type object_status: int

        :param object_version:
            The value to assign to the object_version property of this UpdateTaskFromSQLTask.
        :type object_version: int

        :param identifier:
            The value to assign to the identifier property of this UpdateTaskFromSQLTask.
        :type identifier: str

        :param input_ports:
            The value to assign to the input_ports property of this UpdateTaskFromSQLTask.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this UpdateTaskFromSQLTask.
        :type output_ports: list[oci.data_integration.models.OutputPort]

        :param parameters:
            The value to assign to the parameters property of this UpdateTaskFromSQLTask.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this UpdateTaskFromSQLTask.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param config_provider_delegate:
            The value to assign to the config_provider_delegate property of this UpdateTaskFromSQLTask.
        :type config_provider_delegate: oci.data_integration.models.ConfigProvider

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateTaskFromSQLTask.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        :param script:
            The value to assign to the script property of this UpdateTaskFromSQLTask.
        :type script: oci.data_integration.models.Script

        :param sql_script_type:
            The value to assign to the sql_script_type property of this UpdateTaskFromSQLTask.
            Allowed values for this property are: "STORED_PROCEDURE", "SQL_CODE"
        :type sql_script_type: str

        :param operation:
            The value to assign to the operation property of this UpdateTaskFromSQLTask.
        :type operation: object

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'object_version': 'int',
            'identifier': 'str',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'config_provider_delegate': 'ConfigProvider',
            'registry_metadata': 'RegistryMetadata',
            'script': 'Script',
            'sql_script_type': 'str',
            'operation': 'object'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'object_version': 'objectVersion',
            'identifier': 'identifier',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'config_provider_delegate': 'configProviderDelegate',
            'registry_metadata': 'registryMetadata',
            'script': 'script',
            'sql_script_type': 'sqlScriptType',
            'operation': 'operation'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_status = None
        self._object_version = None
        self._identifier = None
        self._input_ports = None
        self._output_ports = None
        self._parameters = None
        self._op_config_values = None
        self._config_provider_delegate = None
        self._registry_metadata = None
        self._script = None
        self._sql_script_type = None
        self._operation = None
        self._model_type = 'SQL_TASK'

    @property
    def script(self):
        """
        Gets the script of this UpdateTaskFromSQLTask.

        :return: The script of this UpdateTaskFromSQLTask.
        :rtype: oci.data_integration.models.Script
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this UpdateTaskFromSQLTask.

        :param script: The script of this UpdateTaskFromSQLTask.
        :type: oci.data_integration.models.Script
        """
        self._script = script

    @property
    def sql_script_type(self):
        """
        Gets the sql_script_type of this UpdateTaskFromSQLTask.
        Indicates whether the task is invoking a custom SQL script or stored procedure.

        Allowed values for this property are: "STORED_PROCEDURE", "SQL_CODE"


        :return: The sql_script_type of this UpdateTaskFromSQLTask.
        :rtype: str
        """
        return self._sql_script_type

    @sql_script_type.setter
    def sql_script_type(self, sql_script_type):
        """
        Sets the sql_script_type of this UpdateTaskFromSQLTask.
        Indicates whether the task is invoking a custom SQL script or stored procedure.


        :param sql_script_type: The sql_script_type of this UpdateTaskFromSQLTask.
        :type: str
        """
        allowed_values = ["STORED_PROCEDURE", "SQL_CODE"]
        if not value_allowed_none_or_none_sentinel(sql_script_type, allowed_values):
            raise ValueError(
                "Invalid value for `sql_script_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sql_script_type = sql_script_type

    @property
    def operation(self):
        """
        Gets the operation of this UpdateTaskFromSQLTask.
        Describes the shape of the execution result


        :return: The operation of this UpdateTaskFromSQLTask.
        :rtype: object
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this UpdateTaskFromSQLTask.
        Describes the shape of the execution result


        :param operation: The operation of this UpdateTaskFromSQLTask.
        :type: object
        """
        self._operation = operation

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateAutonomousExadataInfrastructureDetails(object):
    """
    Describes the modification parameters for the Autonomous Exadata Infrastructure.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateAutonomousExadataInfrastructureDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateAutonomousExadataInfrastructureDetails.
        :type display_name: str

        :param maintenance_window_details:
            The value to assign to the maintenance_window_details property of this UpdateAutonomousExadataInfrastructureDetails.
        :type maintenance_window_details: oci.database.models.MaintenanceWindow

        :param nsg_ids:
            The value to assign to the nsg_ids property of this UpdateAutonomousExadataInfrastructureDetails.
        :type nsg_ids: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateAutonomousExadataInfrastructureDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateAutonomousExadataInfrastructureDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'maintenance_window_details': 'MaintenanceWindow',
            'nsg_ids': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'maintenance_window_details': 'maintenanceWindowDetails',
            'nsg_ids': 'nsgIds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._maintenance_window_details = None
        self._nsg_ids = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateAutonomousExadataInfrastructureDetails.
        The display name is a user-friendly name for the Autonomous Exadata Infrastructure. The display name does not have to be unique.


        :return: The display_name of this UpdateAutonomousExadataInfrastructureDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateAutonomousExadataInfrastructureDetails.
        The display name is a user-friendly name for the Autonomous Exadata Infrastructure. The display name does not have to be unique.


        :param display_name: The display_name of this UpdateAutonomousExadataInfrastructureDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def maintenance_window_details(self):
        """
        Gets the maintenance_window_details of this UpdateAutonomousExadataInfrastructureDetails.

        :return: The maintenance_window_details of this UpdateAutonomousExadataInfrastructureDetails.
        :rtype: oci.database.models.MaintenanceWindow
        """
        return self._maintenance_window_details

    @maintenance_window_details.setter
    def maintenance_window_details(self, maintenance_window_details):
        """
        Sets the maintenance_window_details of this UpdateAutonomousExadataInfrastructureDetails.

        :param maintenance_window_details: The maintenance_window_details of this UpdateAutonomousExadataInfrastructureDetails.
        :type: oci.database.models.MaintenanceWindow
        """
        self._maintenance_window_details = maintenance_window_details

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this UpdateAutonomousExadataInfrastructureDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this UpdateAutonomousExadataInfrastructureDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this UpdateAutonomousExadataInfrastructureDetails.
        A list of the `OCIDs`__ of the network security groups (NSGs) that this resource belongs to. Setting this to an empty array after the list is created removes the resource from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - Autonomous Databases with private access require at least 1 Network Security Group (NSG). The nsgIds array cannot be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this UpdateAutonomousExadataInfrastructureDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateAutonomousExadataInfrastructureDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateAutonomousExadataInfrastructureDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateAutonomousExadataInfrastructureDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateAutonomousExadataInfrastructureDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateAutonomousExadataInfrastructureDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateAutonomousExadataInfrastructureDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateAutonomousExadataInfrastructureDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateAutonomousExadataInfrastructureDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Deployment(object):
    """
    A container for your OCI GoldenGate resources, such as the OCI GoldenGate deployment console.
    """

    #: A constant which can be used with the lifecycle_state property of a Deployment.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Deployment.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Deployment.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Deployment.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Deployment.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Deployment.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Deployment.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the license_model property of a Deployment.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a Deployment.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    #: A constant which can be used with the deployment_type property of a Deployment.
    #: This constant has a value of "OGG"
    DEPLOYMENT_TYPE_OGG = "OGG"

    def __init__(self, **kwargs):
        """
        Initializes a new Deployment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Deployment.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this Deployment.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Deployment.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Deployment.
        :type compartment_id: str

        :param deployment_backup_id:
            The value to assign to the deployment_backup_id property of this Deployment.
        :type deployment_backup_id: str

        :param time_created:
            The value to assign to the time_created property of this Deployment.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Deployment.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Deployment.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Deployment.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Deployment.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Deployment.
        :type defined_tags: dict(str, dict(str, object))

        :param is_healthy:
            The value to assign to the is_healthy property of this Deployment.
        :type is_healthy: bool

        :param subnet_id:
            The value to assign to the subnet_id property of this Deployment.
        :type subnet_id: str

        :param fqdn:
            The value to assign to the fqdn property of this Deployment.
        :type fqdn: str

        :param license_model:
            The value to assign to the license_model property of this Deployment.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type license_model: str

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this Deployment.
        :type cpu_core_count: int

        :param is_auto_scaling_enabled:
            The value to assign to the is_auto_scaling_enabled property of this Deployment.
        :type is_auto_scaling_enabled: bool

        :param nsg_ids:
            The value to assign to the nsg_ids property of this Deployment.
        :type nsg_ids: list[str]

        :param is_public:
            The value to assign to the is_public property of this Deployment.
        :type is_public: bool

        :param public_ip_address:
            The value to assign to the public_ip_address property of this Deployment.
        :type public_ip_address: str

        :param private_ip_address:
            The value to assign to the private_ip_address property of this Deployment.
        :type private_ip_address: str

        :param deployment_url:
            The value to assign to the deployment_url property of this Deployment.
        :type deployment_url: str

        :param system_tags:
            The value to assign to the system_tags property of this Deployment.
        :type system_tags: dict(str, dict(str, object))

        :param is_latest_version:
            The value to assign to the is_latest_version property of this Deployment.
        :type is_latest_version: bool

        :param deployment_type:
            The value to assign to the deployment_type property of this Deployment.
            Allowed values for this property are: "OGG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type deployment_type: str

        :param ogg_data:
            The value to assign to the ogg_data property of this Deployment.
        :type ogg_data: oci.golden_gate.models.OggDeployment

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'deployment_backup_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'is_healthy': 'bool',
            'subnet_id': 'str',
            'fqdn': 'str',
            'license_model': 'str',
            'cpu_core_count': 'int',
            'is_auto_scaling_enabled': 'bool',
            'nsg_ids': 'list[str]',
            'is_public': 'bool',
            'public_ip_address': 'str',
            'private_ip_address': 'str',
            'deployment_url': 'str',
            'system_tags': 'dict(str, dict(str, object))',
            'is_latest_version': 'bool',
            'deployment_type': 'str',
            'ogg_data': 'OggDeployment'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'deployment_backup_id': 'deploymentBackupId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'is_healthy': 'isHealthy',
            'subnet_id': 'subnetId',
            'fqdn': 'fqdn',
            'license_model': 'licenseModel',
            'cpu_core_count': 'cpuCoreCount',
            'is_auto_scaling_enabled': 'isAutoScalingEnabled',
            'nsg_ids': 'nsgIds',
            'is_public': 'isPublic',
            'public_ip_address': 'publicIpAddress',
            'private_ip_address': 'privateIpAddress',
            'deployment_url': 'deploymentUrl',
            'system_tags': 'systemTags',
            'is_latest_version': 'isLatestVersion',
            'deployment_type': 'deploymentType',
            'ogg_data': 'oggData'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._deployment_backup_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._is_healthy = None
        self._subnet_id = None
        self._fqdn = None
        self._license_model = None
        self._cpu_core_count = None
        self._is_auto_scaling_enabled = None
        self._nsg_ids = None
        self._is_public = None
        self._public_ip_address = None
        self._private_ip_address = None
        self._deployment_url = None
        self._system_tags = None
        self._is_latest_version = None
        self._deployment_type = None
        self._ogg_data = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Deployment.
        The `OCID`__ of the deployment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this Deployment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Deployment.
        The `OCID`__ of the deployment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this Deployment.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this Deployment.
        An object's Display Name.


        :return: The display_name of this Deployment.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Deployment.
        An object's Display Name.


        :param display_name: The display_name of this Deployment.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this Deployment.
        Metadata about this specific object.


        :return: The description of this Deployment.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Deployment.
        Metadata about this specific object.


        :param description: The description of this Deployment.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Deployment.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Deployment.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Deployment.
        The `OCID`__ of the compartment being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Deployment.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def deployment_backup_id(self):
        """
        Gets the deployment_backup_id of this Deployment.
        The `OCID`__ of the backup being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The deployment_backup_id of this Deployment.
        :rtype: str
        """
        return self._deployment_backup_id

    @deployment_backup_id.setter
    def deployment_backup_id(self, deployment_backup_id):
        """
        Sets the deployment_backup_id of this Deployment.
        The `OCID`__ of the backup being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param deployment_backup_id: The deployment_backup_id of this Deployment.
        :type: str
        """
        self._deployment_backup_id = deployment_backup_id

    @property
    def time_created(self):
        """
        Gets the time_created of this Deployment.
        The time the resource was created. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Deployment.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Deployment.
        The time the resource was created. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Deployment.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Deployment.
        The time the resource was last updated. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Deployment.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Deployment.
        The time the resource was last updated. The format is defined by `RFC3339`__, such as `2016-08-25T21:10:29.600Z`.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Deployment.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Deployment.
        Possible lifecycle states.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Deployment.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Deployment.
        Possible lifecycle states.


        :param lifecycle_state: The lifecycle_state of this Deployment.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Deployment.
        Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.


        :return: The lifecycle_details of this Deployment.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Deployment.
        Describes the object's current state in detail. For example, it can be used to provide actionable information for a resource in a Failed state.


        :param lifecycle_details: The lifecycle_details of this Deployment.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Deployment.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Deployment.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Deployment.
        A simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Deployment.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Deployment.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Deployment.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Deployment.
        Tags defined for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Deployment.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def is_healthy(self):
        """
        Gets the is_healthy of this Deployment.
        True if all of the aggregate resources are working correctly.


        :return: The is_healthy of this Deployment.
        :rtype: bool
        """
        return self._is_healthy

    @is_healthy.setter
    def is_healthy(self, is_healthy):
        """
        Sets the is_healthy of this Deployment.
        True if all of the aggregate resources are working correctly.


        :param is_healthy: The is_healthy of this Deployment.
        :type: bool
        """
        self._is_healthy = is_healthy

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this Deployment.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this Deployment.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this Deployment.
        The `OCID`__ of the subnet being referenced.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this Deployment.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def fqdn(self):
        """
        Gets the fqdn of this Deployment.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :return: The fqdn of this Deployment.
        :rtype: str
        """
        return self._fqdn

    @fqdn.setter
    def fqdn(self, fqdn):
        """
        Sets the fqdn of this Deployment.
        A three-label Fully Qualified Domain Name (FQDN) for a resource.


        :param fqdn: The fqdn of this Deployment.
        :type: str
        """
        self._fqdn = fqdn

    @property
    def license_model(self):
        """
        **[Required]** Gets the license_model of this Deployment.
        The Oracle license model that applies to a Deployment.

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The license_model of this Deployment.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this Deployment.
        The Oracle license model that applies to a Deployment.


        :param license_model: The license_model of this Deployment.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            license_model = 'UNKNOWN_ENUM_VALUE'
        self._license_model = license_model

    @property
    def cpu_core_count(self):
        """
        **[Required]** Gets the cpu_core_count of this Deployment.
        The Minimum number of OCPUs to be made available for this Deployment.


        :return: The cpu_core_count of this Deployment.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this Deployment.
        The Minimum number of OCPUs to be made available for this Deployment.


        :param cpu_core_count: The cpu_core_count of this Deployment.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def is_auto_scaling_enabled(self):
        """
        **[Required]** Gets the is_auto_scaling_enabled of this Deployment.
        Indicates if auto scaling is enabled for the Deployment's CPU core count.


        :return: The is_auto_scaling_enabled of this Deployment.
        :rtype: bool
        """
        return self._is_auto_scaling_enabled

    @is_auto_scaling_enabled.setter
    def is_auto_scaling_enabled(self, is_auto_scaling_enabled):
        """
        Sets the is_auto_scaling_enabled of this Deployment.
        Indicates if auto scaling is enabled for the Deployment's CPU core count.


        :param is_auto_scaling_enabled: The is_auto_scaling_enabled of this Deployment.
        :type: bool
        """
        self._is_auto_scaling_enabled = is_auto_scaling_enabled

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this Deployment.
        An array of `Network Security Group`__ OCIDs used to define network access for a deployment.

        __ https://docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm


        :return: The nsg_ids of this Deployment.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this Deployment.
        An array of `Network Security Group`__ OCIDs used to define network access for a deployment.

        __ https://docs.cloud.oracle.com/Content/Network/Concepts/networksecuritygroups.htm


        :param nsg_ids: The nsg_ids of this Deployment.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def is_public(self):
        """
        Gets the is_public of this Deployment.
        True if this object is publicly available.


        :return: The is_public of this Deployment.
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """
        Sets the is_public of this Deployment.
        True if this object is publicly available.


        :param is_public: The is_public of this Deployment.
        :type: bool
        """
        self._is_public = is_public

    @property
    def public_ip_address(self):
        """
        Gets the public_ip_address of this Deployment.
        The public IP address representing the access point for the Deployment.


        :return: The public_ip_address of this Deployment.
        :rtype: str
        """
        return self._public_ip_address

    @public_ip_address.setter
    def public_ip_address(self, public_ip_address):
        """
        Sets the public_ip_address of this Deployment.
        The public IP address representing the access point for the Deployment.


        :param public_ip_address: The public_ip_address of this Deployment.
        :type: str
        """
        self._public_ip_address = public_ip_address

    @property
    def private_ip_address(self):
        """
        Gets the private_ip_address of this Deployment.
        The private IP address in the customer's VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.


        :return: The private_ip_address of this Deployment.
        :rtype: str
        """
        return self._private_ip_address

    @private_ip_address.setter
    def private_ip_address(self, private_ip_address):
        """
        Sets the private_ip_address of this Deployment.
        The private IP address in the customer's VCN representing the access point for the associated endpoint service in the GoldenGate service VCN.


        :param private_ip_address: The private_ip_address of this Deployment.
        :type: str
        """
        self._private_ip_address = private_ip_address

    @property
    def deployment_url(self):
        """
        Gets the deployment_url of this Deployment.
        The URL of a resource.


        :return: The deployment_url of this Deployment.
        :rtype: str
        """
        return self._deployment_url

    @deployment_url.setter
    def deployment_url(self, deployment_url):
        """
        Sets the deployment_url of this Deployment.
        The URL of a resource.


        :param deployment_url: The deployment_url of this Deployment.
        :type: str
        """
        self._deployment_url = deployment_url

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Deployment.
        The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces.  For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this Deployment.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Deployment.
        The system tags associated with this resource, if any. The system tags are set by Oracle Cloud Infrastructure services. Each key is predefined and scoped to namespaces.  For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this Deployment.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    @property
    def is_latest_version(self):
        """
        Gets the is_latest_version of this Deployment.
        Indicates if the resource is the the latest available version.


        :return: The is_latest_version of this Deployment.
        :rtype: bool
        """
        return self._is_latest_version

    @is_latest_version.setter
    def is_latest_version(self, is_latest_version):
        """
        Sets the is_latest_version of this Deployment.
        Indicates if the resource is the the latest available version.


        :param is_latest_version: The is_latest_version of this Deployment.
        :type: bool
        """
        self._is_latest_version = is_latest_version

    @property
    def deployment_type(self):
        """
        **[Required]** Gets the deployment_type of this Deployment.
        The deployment type.

        Allowed values for this property are: "OGG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The deployment_type of this Deployment.
        :rtype: str
        """
        return self._deployment_type

    @deployment_type.setter
    def deployment_type(self, deployment_type):
        """
        Sets the deployment_type of this Deployment.
        The deployment type.


        :param deployment_type: The deployment_type of this Deployment.
        :type: str
        """
        allowed_values = ["OGG"]
        if not value_allowed_none_or_none_sentinel(deployment_type, allowed_values):
            deployment_type = 'UNKNOWN_ENUM_VALUE'
        self._deployment_type = deployment_type

    @property
    def ogg_data(self):
        """
        Gets the ogg_data of this Deployment.

        :return: The ogg_data of this Deployment.
        :rtype: oci.golden_gate.models.OggDeployment
        """
        return self._ogg_data

    @ogg_data.setter
    def ogg_data(self, ogg_data):
        """
        Sets the ogg_data of this Deployment.

        :param ogg_data: The ogg_data of this Deployment.
        :type: oci.golden_gate.models.OggDeployment
        """
        self._ogg_data = ogg_data

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NetworkSourcesVirtualSourceList(object):
    """
    NetworkSourcesVirtualSourceList model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NetworkSourcesVirtualSourceList object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param vcn_id:
            The value to assign to the vcn_id property of this NetworkSourcesVirtualSourceList.
        :type vcn_id: str

        :param ip_ranges:
            The value to assign to the ip_ranges property of this NetworkSourcesVirtualSourceList.
        :type ip_ranges: list[str]

        """
        self.swagger_types = {
            'vcn_id': 'str',
            'ip_ranges': 'list[str]'
        }

        self.attribute_map = {
            'vcn_id': 'vcnId',
            'ip_ranges': 'ipRanges'
        }

        self._vcn_id = None
        self._ip_ranges = None

    @property
    def vcn_id(self):
        """
        Gets the vcn_id of this NetworkSourcesVirtualSourceList.

        :return: The vcn_id of this NetworkSourcesVirtualSourceList.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this NetworkSourcesVirtualSourceList.

        :param vcn_id: The vcn_id of this NetworkSourcesVirtualSourceList.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def ip_ranges(self):
        """
        Gets the ip_ranges of this NetworkSourcesVirtualSourceList.

        :return: The ip_ranges of this NetworkSourcesVirtualSourceList.
        :rtype: list[str]
        """
        return self._ip_ranges

    @ip_ranges.setter
    def ip_ranges(self, ip_ranges):
        """
        Sets the ip_ranges of this NetworkSourcesVirtualSourceList.

        :param ip_ranges: The ip_ranges of this NetworkSourcesVirtualSourceList.
        :type: list[str]
        """
        self._ip_ranges = ip_ranges

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_configuration_metric_group import HostConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostEntities(HostConfigurationMetricGroup):
    """
    Database entities running on the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostEntities object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostEntities.metric_name` attribute
        of this class is ``HOST_ENTITIES`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostEntities.
            Allowed values for this property are: "HOST_PRODUCT", "HOST_RESOURCE_ALLOCATION", "HOST_MEMORY_CONFIGURATION", "HOST_HARDWARE_CONFIGURATION", "HOST_CPU_HARDWARE_CONFIGURATION", "HOST_NETWORK_CONFIGURATION", "HOST_ENTITES"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostEntities.
        :type time_collected: datetime

        :param entity_name:
            The value to assign to the entity_name property of this HostEntities.
        :type entity_name: str

        :param entity_type:
            The value to assign to the entity_type property of this HostEntities.
        :type entity_type: str

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'entity_name': 'str',
            'entity_type': 'str'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'entity_name': 'entityName',
            'entity_type': 'entityType'
        }

        self._metric_name = None
        self._time_collected = None
        self._entity_name = None
        self._entity_type = None
        self._metric_name = 'HOST_ENTITIES'

    @property
    def entity_name(self):
        """
        **[Required]** Gets the entity_name of this HostEntities.
        Name of the database entity


        :return: The entity_name of this HostEntities.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this HostEntities.
        Name of the database entity


        :param entity_name: The entity_name of this HostEntities.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this HostEntities.
        Type of the database entity


        :return: The entity_type of this HostEntities.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this HostEntities.
        Type of the database entity


        :param entity_type: The entity_type of this HostEntities.
        :type: str
        """
        self._entity_type = entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceStatisticsAggregation(object):
    """
    Contains database details and resource statistics
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceStatisticsAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param database_details:
            The value to assign to the database_details property of this ResourceStatisticsAggregation.
        :type database_details: oci.opsi.models.DatabaseDetails

        :param current_statistics:
            The value to assign to the current_statistics property of this ResourceStatisticsAggregation.
        :type current_statistics: oci.opsi.models.ResourceStatistics

        """
        self.swagger_types = {
            'database_details': 'DatabaseDetails',
            'current_statistics': 'ResourceStatistics'
        }

        self.attribute_map = {
            'database_details': 'databaseDetails',
            'current_statistics': 'currentStatistics'
        }

        self._database_details = None
        self._current_statistics = None

    @property
    def database_details(self):
        """
        Gets the database_details of this ResourceStatisticsAggregation.

        :return: The database_details of this ResourceStatisticsAggregation.
        :rtype: oci.opsi.models.DatabaseDetails
        """
        return self._database_details

    @database_details.setter
    def database_details(self, database_details):
        """
        Sets the database_details of this ResourceStatisticsAggregation.

        :param database_details: The database_details of this ResourceStatisticsAggregation.
        :type: oci.opsi.models.DatabaseDetails
        """
        self._database_details = database_details

    @property
    def current_statistics(self):
        """
        Gets the current_statistics of this ResourceStatisticsAggregation.

        :return: The current_statistics of this ResourceStatisticsAggregation.
        :rtype: oci.opsi.models.ResourceStatistics
        """
        return self._current_statistics

    @current_statistics.setter
    def current_statistics(self, current_statistics):
        """
        Sets the current_statistics of this ResourceStatisticsAggregation.

        :param current_statistics: The current_statistics of this ResourceStatisticsAggregation.
        :type: oci.opsi.models.ResourceStatistics
        """
        self._current_statistics = current_statistics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClusterMigrateToNativeVcnDetails(object):
    """
    The properties that define a request to migrate a cluster to Native VCN.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ClusterMigrateToNativeVcnDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param endpoint_config:
            The value to assign to the endpoint_config property of this ClusterMigrateToNativeVcnDetails.
        :type endpoint_config: oci.container_engine.models.ClusterEndpointConfig

        :param decommission_delay_duration:
            The value to assign to the decommission_delay_duration property of this ClusterMigrateToNativeVcnDetails.
        :type decommission_delay_duration: str

        """
        self.swagger_types = {
            'endpoint_config': 'ClusterEndpointConfig',
            'decommission_delay_duration': 'str'
        }

        self.attribute_map = {
            'endpoint_config': 'endpointConfig',
            'decommission_delay_duration': 'decommissionDelayDuration'
        }

        self._endpoint_config = None
        self._decommission_delay_duration = None

    @property
    def endpoint_config(self):
        """
        **[Required]** Gets the endpoint_config of this ClusterMigrateToNativeVcnDetails.
        The network configuration for access to the Cluster control plane.


        :return: The endpoint_config of this ClusterMigrateToNativeVcnDetails.
        :rtype: oci.container_engine.models.ClusterEndpointConfig
        """
        return self._endpoint_config

    @endpoint_config.setter
    def endpoint_config(self, endpoint_config):
        """
        Sets the endpoint_config of this ClusterMigrateToNativeVcnDetails.
        The network configuration for access to the Cluster control plane.


        :param endpoint_config: The endpoint_config of this ClusterMigrateToNativeVcnDetails.
        :type: oci.container_engine.models.ClusterEndpointConfig
        """
        self._endpoint_config = endpoint_config

    @property
    def decommission_delay_duration(self):
        """
        Gets the decommission_delay_duration of this ClusterMigrateToNativeVcnDetails.
        The optional override of the non-native endpoint decommission time after migration is complete. Defaults to 30 days.


        :return: The decommission_delay_duration of this ClusterMigrateToNativeVcnDetails.
        :rtype: str
        """
        return self._decommission_delay_duration

    @decommission_delay_duration.setter
    def decommission_delay_duration(self, decommission_delay_duration):
        """
        Sets the decommission_delay_duration of this ClusterMigrateToNativeVcnDetails.
        The optional override of the non-native endpoint decommission time after migration is complete. Defaults to 30 days.


        :param decommission_delay_duration: The decommission_delay_duration of this ClusterMigrateToNativeVcnDetails.
        :type: str
        """
        self._decommission_delay_duration = decommission_delay_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerScanSettings(object):
    """
    A collection of container scan settings
    """

    #: A constant which can be used with the scan_level property of a ContainerScanSettings.
    #: This constant has a value of "NONE"
    SCAN_LEVEL_NONE = "NONE"

    #: A constant which can be used with the scan_level property of a ContainerScanSettings.
    #: This constant has a value of "STANDARD"
    SCAN_LEVEL_STANDARD = "STANDARD"

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerScanSettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param scan_level:
            The value to assign to the scan_level property of this ContainerScanSettings.
            Allowed values for this property are: "NONE", "STANDARD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type scan_level: str

        """
        self.swagger_types = {
            'scan_level': 'str'
        }

        self.attribute_map = {
            'scan_level': 'scanLevel'
        }

        self._scan_level = None

    @property
    def scan_level(self):
        """
        **[Required]** Gets the scan_level of this ContainerScanSettings.
        The scan level

        Allowed values for this property are: "NONE", "STANDARD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The scan_level of this ContainerScanSettings.
        :rtype: str
        """
        return self._scan_level

    @scan_level.setter
    def scan_level(self, scan_level):
        """
        Sets the scan_level of this ContainerScanSettings.
        The scan level


        :param scan_level: The scan_level of this ContainerScanSettings.
        :type: str
        """
        allowed_values = ["NONE", "STANDARD"]
        if not value_allowed_none_or_none_sentinel(scan_level, allowed_values):
            scan_level = 'UNKNOWN_ENUM_VALUE'
        self._scan_level = scan_level

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Entity(object):
    """
    entity object
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Entity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param offset:
            The value to assign to the offset property of this Entity.
        :type offset: int

        :param length:
            The value to assign to the length property of this Entity.
        :type length: int

        :param text:
            The value to assign to the text property of this Entity.
        :type text: str

        :param type:
            The value to assign to the type property of this Entity.
        :type type: str

        :param is_pii:
            The value to assign to the is_pii property of this Entity.
        :type is_pii: bool

        :param score:
            The value to assign to the score property of this Entity.
        :type score: float

        """
        self.swagger_types = {
            'offset': 'int',
            'length': 'int',
            'text': 'str',
            'type': 'str',
            'is_pii': 'bool',
            'score': 'float'
        }

        self.attribute_map = {
            'offset': 'offset',
            'length': 'length',
            'text': 'text',
            'type': 'type',
            'is_pii': 'isPii',
            'score': 'score'
        }

        self._offset = None
        self._length = None
        self._text = None
        self._type = None
        self._is_pii = None
        self._score = None

    @property
    def offset(self):
        """
        Gets the offset of this Entity.
        The number of Unicode code points preceding this entity in the submitted text.


        :return: The offset of this Entity.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """
        Sets the offset of this Entity.
        The number of Unicode code points preceding this entity in the submitted text.


        :param offset: The offset of this Entity.
        :type: int
        """
        self._offset = offset

    @property
    def length(self):
        """
        Gets the length of this Entity.
        Length of text


        :return: The length of this Entity.
        :rtype: int
        """
        return self._length

    @length.setter
    def length(self, length):
        """
        Sets the length of this Entity.
        Length of text


        :param length: The length of this Entity.
        :type: int
        """
        self._length = length

    @property
    def text(self):
        """
        Gets the text of this Entity.
        Entity text like name of person, location, and so on.


        :return: The text of this Entity.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this Entity.
        Entity text like name of person, location, and so on.


        :param text: The text of this Entity.
        :type: str
        """
        self._text = text

    @property
    def type(self):
        """
        Gets the type of this Entity.
        Type of entity text like PER, LOC, GPE and NOPE.


        :return: The type of this Entity.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Entity.
        Type of entity text like PER, LOC, GPE and NOPE.


        :param type: The type of this Entity.
        :type: str
        """
        self._type = type

    @property
    def is_pii(self):
        """
        Gets the is_pii of this Entity.
        This flag is to indicate if it is PII entity or not.


        :return: The is_pii of this Entity.
        :rtype: bool
        """
        return self._is_pii

    @is_pii.setter
    def is_pii(self, is_pii):
        """
        Sets the is_pii of this Entity.
        This flag is to indicate if it is PII entity or not.


        :param is_pii: The is_pii of this Entity.
        :type: bool
        """
        self._is_pii = is_pii

    @property
    def score(self):
        """
        Gets the score of this Entity.
        Score or confidence for prediction.


        :return: The score of this Entity.
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """
        Sets the score of this Entity.
        Score or confidence for prediction.


        :param score: The score of this Entity.
        :type: float
        """
        self._score = score

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateScheduleDetails(object):
    """
    The details for creating a schedule.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateScheduleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this CreateScheduleDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateScheduleDetails.
        :type model_version: str

        :param name:
            The value to assign to the name property of this CreateScheduleDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateScheduleDetails.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this CreateScheduleDetails.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this CreateScheduleDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateScheduleDetails.
        :type identifier: str

        :param frequency_details:
            The value to assign to the frequency_details property of this CreateScheduleDetails.
        :type frequency_details: oci.data_integration.models.AbstractFrequencyDetails

        :param timezone:
            The value to assign to the timezone property of this CreateScheduleDetails.
        :type timezone: str

        :param is_daylight_adjustment_enabled:
            The value to assign to the is_daylight_adjustment_enabled property of this CreateScheduleDetails.
        :type is_daylight_adjustment_enabled: bool

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateScheduleDetails.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'frequency_details': 'AbstractFrequencyDetails',
            'timezone': 'str',
            'is_daylight_adjustment_enabled': 'bool',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'frequency_details': 'frequencyDetails',
            'timezone': 'timezone',
            'is_daylight_adjustment_enabled': 'isDaylightAdjustmentEnabled',
            'registry_metadata': 'registryMetadata'
        }

        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._frequency_details = None
        self._timezone = None
        self._is_daylight_adjustment_enabled = None
        self._registry_metadata = None

    @property
    def key(self):
        """
        Gets the key of this CreateScheduleDetails.
        Generated key that can be used in API calls to identify schedule. On scenarios where reference to the schedule is needed, a value can be passed in create.


        :return: The key of this CreateScheduleDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this CreateScheduleDetails.
        Generated key that can be used in API calls to identify schedule. On scenarios where reference to the schedule is needed, a value can be passed in create.


        :param key: The key of this CreateScheduleDetails.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this CreateScheduleDetails.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :return: The model_version of this CreateScheduleDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this CreateScheduleDetails.
        This is a version number that is used by the service to upgrade objects if needed through releases of the service.


        :param model_version: The model_version of this CreateScheduleDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateScheduleDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this CreateScheduleDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateScheduleDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this CreateScheduleDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateScheduleDetails.
        Detailed description for the object.


        :return: The description of this CreateScheduleDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateScheduleDetails.
        Detailed description for the object.


        :param description: The description of this CreateScheduleDetails.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this CreateScheduleDetails.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :return: The object_version of this CreateScheduleDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this CreateScheduleDetails.
        This is used by the service for optimistic locking of the object, to prevent multiple users from simultaneously updating the object.


        :param object_version: The object_version of this CreateScheduleDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this CreateScheduleDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this CreateScheduleDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this CreateScheduleDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this CreateScheduleDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this CreateScheduleDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this CreateScheduleDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this CreateScheduleDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this CreateScheduleDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def frequency_details(self):
        """
        Gets the frequency_details of this CreateScheduleDetails.

        :return: The frequency_details of this CreateScheduleDetails.
        :rtype: oci.data_integration.models.AbstractFrequencyDetails
        """
        return self._frequency_details

    @frequency_details.setter
    def frequency_details(self, frequency_details):
        """
        Sets the frequency_details of this CreateScheduleDetails.

        :param frequency_details: The frequency_details of this CreateScheduleDetails.
        :type: oci.data_integration.models.AbstractFrequencyDetails
        """
        self._frequency_details = frequency_details

    @property
    def timezone(self):
        """
        Gets the timezone of this CreateScheduleDetails.
        The timezone for the schedule.


        :return: The timezone of this CreateScheduleDetails.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this CreateScheduleDetails.
        The timezone for the schedule.


        :param timezone: The timezone of this CreateScheduleDetails.
        :type: str
        """
        self._timezone = timezone

    @property
    def is_daylight_adjustment_enabled(self):
        """
        Gets the is_daylight_adjustment_enabled of this CreateScheduleDetails.
        A flag to indicate whether daylight adjustment should be considered or not.


        :return: The is_daylight_adjustment_enabled of this CreateScheduleDetails.
        :rtype: bool
        """
        return self._is_daylight_adjustment_enabled

    @is_daylight_adjustment_enabled.setter
    def is_daylight_adjustment_enabled(self, is_daylight_adjustment_enabled):
        """
        Sets the is_daylight_adjustment_enabled of this CreateScheduleDetails.
        A flag to indicate whether daylight adjustment should be considered or not.


        :param is_daylight_adjustment_enabled: The is_daylight_adjustment_enabled of this CreateScheduleDetails.
        :type: bool
        """
        self._is_daylight_adjustment_enabled = is_daylight_adjustment_enabled

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this CreateScheduleDetails.

        :return: The registry_metadata of this CreateScheduleDetails.
        :rtype: oci.data_integration.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this CreateScheduleDetails.

        :param registry_metadata: The registry_metadata of this CreateScheduleDetails.
        :type: oci.data_integration.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AgreementSummary(object):
    """
    The model for a summary of an end user license agreement.
    """

    #: A constant which can be used with the author property of a AgreementSummary.
    #: This constant has a value of "ORACLE"
    AUTHOR_ORACLE = "ORACLE"

    #: A constant which can be used with the author property of a AgreementSummary.
    #: This constant has a value of "PARTNER"
    AUTHOR_PARTNER = "PARTNER"

    #: A constant which can be used with the author property of a AgreementSummary.
    #: This constant has a value of "PII"
    AUTHOR_PII = "PII"

    def __init__(self, **kwargs):
        """
        Initializes a new AgreementSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AgreementSummary.
        :type id: str

        :param content_url:
            The value to assign to the content_url property of this AgreementSummary.
        :type content_url: str

        :param author:
            The value to assign to the author property of this AgreementSummary.
            Allowed values for this property are: "ORACLE", "PARTNER", "PII", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type author: str

        :param prompt:
            The value to assign to the prompt property of this AgreementSummary.
        :type prompt: str

        """
        self.swagger_types = {
            'id': 'str',
            'content_url': 'str',
            'author': 'str',
            'prompt': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'content_url': 'contentUrl',
            'author': 'author',
            'prompt': 'prompt'
        }

        self._id = None
        self._content_url = None
        self._author = None
        self._prompt = None

    @property
    def id(self):
        """
        Gets the id of this AgreementSummary.
        The unique identifier for the agreement.


        :return: The id of this AgreementSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AgreementSummary.
        The unique identifier for the agreement.


        :param id: The id of this AgreementSummary.
        :type: str
        """
        self._id = id

    @property
    def content_url(self):
        """
        Gets the content_url of this AgreementSummary.
        The content URL of the agreement.


        :return: The content_url of this AgreementSummary.
        :rtype: str
        """
        return self._content_url

    @content_url.setter
    def content_url(self, content_url):
        """
        Sets the content_url of this AgreementSummary.
        The content URL of the agreement.


        :param content_url: The content_url of this AgreementSummary.
        :type: str
        """
        self._content_url = content_url

    @property
    def author(self):
        """
        Gets the author of this AgreementSummary.
        Who authored the agreement.

        Allowed values for this property are: "ORACLE", "PARTNER", "PII", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The author of this AgreementSummary.
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """
        Sets the author of this AgreementSummary.
        Who authored the agreement.


        :param author: The author of this AgreementSummary.
        :type: str
        """
        allowed_values = ["ORACLE", "PARTNER", "PII"]
        if not value_allowed_none_or_none_sentinel(author, allowed_values):
            author = 'UNKNOWN_ENUM_VALUE'
        self._author = author

    @property
    def prompt(self):
        """
        Gets the prompt of this AgreementSummary.
        Textual prompt to read and accept the agreement.


        :return: The prompt of this AgreementSummary.
        :rtype: str
        """
        return self._prompt

    @prompt.setter
    def prompt(self, prompt):
        """
        Sets the prompt of this AgreementSummary.
        Textual prompt to read and accept the agreement.


        :param prompt: The prompt of this AgreementSummary.
        :type: str
        """
        self._prompt = prompt

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .mount_type_details import MountTypeDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SelfMountDetails(MountTypeDetails):
    """
    Used for creating NFS Self mount backup destinations for non-autonomous ExaCC.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SelfMountDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database.models.SelfMountDetails.mount_type` attribute
        of this class is ``SELF_MOUNT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param mount_type:
            The value to assign to the mount_type property of this SelfMountDetails.
            Allowed values for this property are: "SELF_MOUNT", "AUTOMATED_MOUNT"
        :type mount_type: str

        :param local_mount_point_path:
            The value to assign to the local_mount_point_path property of this SelfMountDetails.
        :type local_mount_point_path: str

        """
        self.swagger_types = {
            'mount_type': 'str',
            'local_mount_point_path': 'str'
        }

        self.attribute_map = {
            'mount_type': 'mountType',
            'local_mount_point_path': 'localMountPointPath'
        }

        self._mount_type = None
        self._local_mount_point_path = None
        self._mount_type = 'SELF_MOUNT'

    @property
    def local_mount_point_path(self):
        """
        **[Required]** Gets the local_mount_point_path of this SelfMountDetails.
        The local directory path on each VM cluster node where the NFS server location is mounted. The local directory path and the NFS server location must each be the same across all of the VM cluster nodes. Ensure that the NFS mount is maintained continuously on all of the VM cluster nodes.


        :return: The local_mount_point_path of this SelfMountDetails.
        :rtype: str
        """
        return self._local_mount_point_path

    @local_mount_point_path.setter
    def local_mount_point_path(self, local_mount_point_path):
        """
        Sets the local_mount_point_path of this SelfMountDetails.
        The local directory path on each VM cluster node where the NFS server location is mounted. The local directory path and the NFS server location must each be the same across all of the VM cluster nodes. Ensure that the NFS mount is maintained continuously on all of the VM cluster nodes.


        :param local_mount_point_path: The local_mount_point_path of this SelfMountDetails.
        :type: str
        """
        self._local_mount_point_path = local_mount_point_path

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
